@@ -6,8 +6,8 @@
 #' @param y response variable vector
 #' @param mu predicted mean vector
 #' @param sigma predicted covariance matrix
-#' @param mh logical indicating whether to return to a Mahalanobis distance value (\code{mh = TRUE}) or
-#'        a score value (\code{mh = FALSE})
+#' @param md logical indicating whether to return to a Mahalanobis distance value (\code{md = TRUE}) and score value or
+#'        only a score value (\code{md = FALSE})
 #' @return a numerical value
 #'
 #'
@@ -41,15 +41,15 @@
 #'
 
 
-score <- function(y, mu, sigma, mh=FALSE) {
+score <- function(y, mu, sigma, md=FALSE) {
   R <- chol(sigma)
   logdet <- 2*sum(log(diag(R)))
   mh_dist <- crossprod(crossprod(solve(R), y - mu)) # mahalanobis distance
-  if(mh) {
-    return(mh_dist)
+  mh_dist <- ifelse(mh_dist > 0 , mh_dist, 0) # if mahalanobis distance is negative, 0
+  score <- (-logdet - mh_dist) / length(y)
+  if(md) {
+    return(list(score=c(score), md=c(mh_dist)))
   } else {
-    mh_dist <- ifelse(mh_dist > 0 , mh_dist, 0) # if mahalanobis distance is negative, 0
-    score <- (-logdet - mh_dist) / length(y)
     return(c(score))
   }
 }
